@@ -1,18 +1,17 @@
 #' Create interactive vertical intervals: lines, crossbars & errorbars
 #'
 #' @description
-#' These geometries are based on \code{\link[ggplot2]{geom_crossbar}},
-#' \code{\link[ggplot2]{geom_errorbar}}, \code{\link[ggplot2]{geom_linerange}}
-#' and \code{\link[ggplot2]{geom_pointrange}}.
+#' These geometries are based on [geom_crossbar()], [geom_errorbar()],
+#' [geom_linerange()] and [geom_pointrange()].
 #' See the documentation for those functions for more details.
 #'
 #' @param ... arguments passed to base function,
-#' plus any of the \code{\link{interactive_parameters}}.
+#' plus any of the [interactive_parameters()].
 #' @inheritSection interactive_parameters Details for geom_*_interactive functions
 #' @examples
 #' # add interactive intervals -------
 #' @example examples/geom_crossbar_interactive.R
-#' @seealso \code{\link{girafe}}
+#' @seealso [girafe()]
 #' @export
 geom_crossbar_interactive <- function(...)
   layer_interactive(geom_crossbar, ...)
@@ -33,7 +32,10 @@ GeomInteractiveCrossbar <- ggproto(
                         panel_params,
                         coord,
                         fatten = 2.5,
-                        width = NULL) {
+                        width = NULL,
+                        flipped_aes = FALSE) {
+    data <- flip_data(data, flipped_aes)
+
     middle <-
       transform(
         data,
@@ -111,6 +113,8 @@ GeomInteractiveCrossbar <- ggproto(
       )
       box <- copy_interactive_attrs(data, box, 5)
     }
+    box <- flip_data(box, flipped_aes)
+    middle <- flip_data(middle, flipped_aes)
 
     ggname("geom_interactive_crossbar", gTree(
       children = gList(
