@@ -1,4 +1,4 @@
-#' Create interactive dot plot
+#' @title Create interactive dot plots
 #'
 #' @description
 #' This geometry is based on [geom_dotplot()].
@@ -8,19 +8,8 @@
 #' plus any of the [interactive_parameters()].
 #' @inheritSection interactive_parameters Details for geom_*_interactive functions
 #' @examples
-#' library(ggplot2)
-#' library(ggiraph)
-#'
-#' gg_point = ggplot(
-#'   data = mtcars,
-#'   mapping = aes(
-#'     x = factor(vs), fill = factor(cyl), y = mpg,
-#'     tooltip = row.names(mtcars))) +
-#'   geom_dotplot_interactive(binaxis = "y",
-#'     stackdir = "center", position = "dodge")
-#'
-#' x <- girafe(ggobj = gg_point)
-#' if( interactive() ) print(x)
+#' # add interactive dot plots to a ggplot -------
+#' @example examples/geom_dotplot_interactive.R
 #' @seealso [girafe()]
 #' @export
 geom_dotplot_interactive <- function(...)
@@ -38,10 +27,14 @@ GeomInteractiveDotplot <- ggproto(
     gr <- GeomDotplot$draw_key(data, params, size)
     add_interactive_attrs(gr, data, data_attr = "key-id")
   },
-  draw_group = function (data, ...)
-  {
-    zz <- GeomDotplot$draw_group(data, ...)
-    add_interactive_attrs(zz, data)
+  parameters = function(extra = FALSE) {
+    GeomDotplot$parameters(extra = extra)
+  },
+  draw_group = function(data, panel_params, coord, ...) {
+    zz <- GeomDotplot$draw_group(data, panel_params, coord, ...)
+    coords <- coord$transform(data, panel_params)
+    coords <- force_interactive_aes_to_char(coords)
+    add_interactive_attrs(zz, coords)
   }
 )
 
@@ -51,4 +44,3 @@ makeContext.interactive_dotstack_grob <- function(x, recording = TRUE) {
   gr <- add_interactive_attrs(gr, x)
   gr
 }
-
