@@ -38,6 +38,9 @@ GeomInteractiveLabel <- ggproto(
       label.size = label.size
     )
     coords <- coord$transform(data, panel_params)
+    if (is.null(coords$tooltip_fill)) {
+      coords$tooltip_fill <- coords$fill
+    }
     coords <- force_interactive_aes_to_char(coords)
     add_interactive_attrs(gr, coords)
   }
