@@ -1,16 +1,16 @@
 #' @title Create interactive polygons
 #'
 #' @description
-#' The geometry is based on \code{\link[ggplot2]{geom_polygon}}.
+#' The geometry is based on [geom_polygon()].
 #' See the documentation for those functions for more details.
 #'
 #' @param ... arguments passed to base function,
-#' plus any of the \code{\link{interactive_parameters}}.
+#' plus any of the [interactive_parameters()].
 #' @inheritSection interactive_parameters Details for geom_*_interactive functions
 #' @examples
 #' # add interactive polygons to a ggplot -------
 #' @example examples/geom_polygon_interactive.R
-#' @seealso \code{\link{girafe}}
+#' @seealso [girafe()]
 #' @export
 geom_polygon_interactive <- function(...)
   layer_interactive(geom_polygon, ...)
@@ -65,7 +65,7 @@ GeomInteractivePolygon <- ggproto(
       add_interactive_attrs(gr, munched)
     } else {
       if (utils::packageVersion('grid') < "3.6") {
-        stop("Polygons with holes requires R 3.6 or above", call. = FALSE)
+        abort("Polygons with holes requires R 3.6 or above")
       }
       # Sort by group to make sure that colors, fill, etc. come in same order
       munched <- munched[order(munched$group, munched$subgroup),]
