@@ -1,14 +1,14 @@
 #' @title Create interactive path grob
 #'
 #' @description
-#' The grob is based on \code{\link[grid]{pathGrob}}.
+#' The grob is based on [pathGrob()].
 #' See the documentation for that function for more details.
 #'
 #' @param ... arguments passed to base function,
-#' plus any of the \code{\link{interactive_parameters}}.
+#' plus any of the [interactive_parameters()].
 #' @return An interactive grob object.
 #' @inheritSection interactive_parameters Details for interactive_*_grob functions
-#' @seealso \code{\link{girafe}}
+#' @seealso [girafe()]
 #' @export
 interactive_path_grob <- function(...) {
   grob_interactive(grid::pathGrob, ...)
@@ -17,7 +17,7 @@ interactive_path_grob <- function(...) {
 #' @export
 drawDetails.interactive_path_grob <- function(x, recording) {
   dsvg_tracer_on()
-  do.call(grid.path, x[grob_argnames(x = x, grob = grid::pathGrob)])
+  NextMethod()
   ids <- dsvg_tracer_off()
   if (length(ids) > 0) {
     # if pathId is specified use that (polygons with holes for example)
