@@ -9,21 +9,35 @@
 #' If this is supplied a tooltip is shown when the element is hovered.
 #' Plain text or html is supported.
 #'
+#' To use html markup it is advised to use [htmltools::HTML()] function
+#' in order to mark the text as html markup.
+#' If the text is not marked as html and no opening/closing tags were detected,
+#' then any existing newline characters (`\r\n`, `\r` and `\n`)
+#' are replaced with the `<br/>` tag.
+#'
 #' @param onclick Javascript code to associate with one or more elements.
 #' This code will be executed when the element is clicked.
 #'
 #' @param hover_css Individual css style associate with one or more elements.
 #' This css style is applied when the element is hovered and overrides the default style,
-#' set via [opts_hover()] or [opts_hover_key()].
+#' set via [opts_hover()], [opts_hover_key()] or [opts_hover_theme()].
+#' It can also be constructed with \code{\link{girafe_css}},
+#' to give more control over the css for different element types (see [opts_hover()] note).
 #'
 #' @param selected_css Individual css style associate with one or more elements.
 #' This css style is applied when the element is selected and overrides the default style,
-#' set via [opts_selection()] or [opts_selection_key()].
+#' set via [opts_selection()], [opts_selection_key()] or [opts_selection_theme()].
+#' It can also be constructed with \code{\link{girafe_css}},
+#' to give more control over the css for different element types (see [opts_selection()] note).
 #'
 #' @param data_id Identifier to associate with one or more elements.
 #' This is mandatory parameter if hover and selection interactivity is desired.
 #' Identifiers are available as reactive input values in Shiny applications.
 #'
+#' @param tooltip_fill Color to use for tooltip background when [opts_tooltip()] `use_fill` is TRUE.
+#' Useful for setting the tooltip background color in [geom_text_interactive()] or
+#' [geom_label_interactive()], when the geom text color may be the same as the tooltip text color.
+#'
 #' @section Details for geom_*_interactive functions:
 #' The interactive parameters can be supplied with two ways:
 #' \itemize{
@@ -102,7 +116,8 @@ IPAR_DEFAULTS <- list(
   tooltip = NULL,
   onclick = NULL,
   hover_css = NULL,
-  selected_css = NULL
+  selected_css = NULL,
+  tooltip_fill = NULL
 )
 
 IPAR_NAMES <- names(IPAR_DEFAULTS)
@@ -267,7 +282,7 @@ add_interactive_attrs <- function(gr,
     # some grobs have class name which contains "grob" already, like rastergrob
     # and labelgrob, so they end up named like interactive_rastergrob_grob.
     # we normalize the name here, to use class interactive_raster_grob.
-    cl <- sub("grob_grob", "_grob", cl)
+    cl <- sub("grob_grob", "_grob", cl, ignore.case = TRUE)
   }
   # just extend the class, so that it inherits other grob methods
   class(gr) <- c(cl, class(gr))
