@@ -57,6 +57,14 @@ set_attr = function( ids, attribute, str ){
   stopifnot( is.character(str) )
   stopifnot( is.numeric(ids) )
 
+  if (length(str) == 1 && length(ids) > 1) {
+    str <- rep(str, length(ids))
+  }
+  if (length(ids) %% length(str) < 1 &&
+      length(ids) != length(str)) {
+    str <- rep(str, each = length(ids) %/% length(str))
+  }
+
   if( length(ids) != length(str) ){
     stop("ids don't have the same length than str (most often, it occurs because of clipping)")
   }
