@@ -6,9 +6,9 @@
 
 #include "utils.h"
 #include "Rcpp.h"
-#include <gdtools.h>
 #include <string.h>
 #include "fonts.h"
+#include "raster.h"
 #include "R_ext/GraphicsEngine.h"
 #include "a_color.h"
 #include <locale>
@@ -36,9 +36,6 @@ public:
   int tracer_is_init;
 
   Rcpp::List system_aliases;
-  Rcpp::List user_aliases;
-
-  XPtrCairoContext cc;
 
   DSVG_dev(std::string filename_, bool standalone_, bool setdims_,
            std::string canvas_id_,
@@ -58,9 +55,7 @@ public:
       tracer_last_elt(-1),
       tracer_on(0),
       tracer_is_init(0),
-      system_aliases(Rcpp::wrap(aliases_["system"])),
-      user_aliases(Rcpp::wrap(aliases_["user"])),
-      cc(gdtools::context_create() ) {
+      system_aliases(Rcpp::wrap(aliases_["system"])) {
     file = fopen(R_ExpandFileName(filename.c_str()), "w");
     clipleft = 0.0;
     clipright = width_;
@@ -195,33 +190,29 @@ private:
   }
 };
 
+
 static void dsvg_metric_info(int c, const pGEcontext gc, double* ascent,
                              double* descent, double* width, pDevDesc dd) {
   DSVG_dev *svgd = (DSVG_dev*) dd->deviceSpecific;
 
-  bool Unicode = mbcslocale;
   if (c < 0) {
-    Unicode = TRUE;
     c = -c;
   }
-  char str[16];
-  if (!c) {
-    str[0]='M'; str[1]='g'; str[2]=0;
-  } else if (Unicode) {
-    Rf_ucstoutf8(str, (unsigned int) c);
-  } else {
-    str[0] = (char) c;
-    str[1] = '\0';
+
+  std::string fontname_ = fontname(gc->fontfamily, gc->fontface, svgd->system_aliases);
+  FontSettings font = get_font_file(fontname_.c_str(), gc->fontface);
+  int error = glyph_metrics(c, font.file, font.index, gc->ps * gc->cex, 1e4, ascent, descent, width);
+
+  if (error != 0) {
+    *ascent = 0;
+    *descent = 0;
+    *width = 0;
   }
+  double mod = 72./1e4;
+  *ascent *= mod;
+  *descent *= mod;
+  *width *= mod;
 
-  std::string file = fontfile(gc->fontfamily, gc->fontface, svgd->user_aliases);
-  std::string name = fontname(gc->fontfamily, gc->fontface, svgd->system_aliases, svgd->user_aliases);
-  gdtools::context_set_font(svgd->cc, name, gc->cex * gc->ps, is_bold(gc->fontface), is_italic(gc->fontface), file);
-  FontMetric fm = gdtools::context_extents(svgd->cc, std::string(str));
-
-  *ascent = fm.ascent;
-  *descent = fm.descent;
-  *width = fm.width;
 }
 
 static void dsvg_clip(double x0, double x1, double y0, double y1, pDevDesc dd) {
@@ -354,13 +345,21 @@ void dsvg_path(double *x, double *y,
 }
 
 static double dsvg_strwidth_utf8(const char *str, const pGEcontext gc, pDevDesc dd) {
-  DSVG_dev *svgd = (DSVG_dev*) dd->deviceSpecific;
 
-  std::string file = fontfile(gc->fontfamily, gc->fontface, svgd->user_aliases);
-  std::string name = fontname(gc->fontfamily, gc->fontface, svgd->system_aliases, svgd->user_aliases);
-  gdtools::context_set_font(svgd->cc, name, gc->cex * gc->ps, is_bold(gc->fontface), is_italic(gc->fontface), file);
-  FontMetric fm = gdtools::context_extents(svgd->cc, std::string(str));
-  return fm.width;
+  DSVG_dev *svgd = (DSVG_dev*) dd->deviceSpecific;
+  std::string fontname_ = fontname(gc->fontfamily, gc->fontface, svgd->system_aliases);
+
+  FontSettings font = get_font_file(fontname_.c_str(), gc->fontface);
+
+  double width = 0.0;
+
+  int error = string_width(str, font.file, font.index, gc->ps * gc->cex, 1e4, 1, &width);
+
+  if (error != 0) {
+    width = 0.0;
+  }
+
+  return width * 72. / 1e4;
 }
 static double dsvg_strwidth(const char *str, const pGEcontext gc, pDevDesc dd) {
   return dsvg_strwidth_utf8(Rf_translateCharUTF8(Rf_mkChar(str)), gc, dd);
@@ -432,7 +431,7 @@ static void dsvg_text_utf8(double x, double y, const char *str, double rot,
     set_fill(text, gc->col);
   } // black
 
-  std::string font = fontname(gc->fontfamily, gc->fontface, svgd->system_aliases, svgd->user_aliases);
+  std::string font = fontname(gc->fontfamily, gc->fontface, svgd->system_aliases);
   set_attr(text, "font-family", font.c_str());
 
   text->SetText(str);
@@ -466,12 +465,7 @@ static void dsvg_raster(unsigned int *raster, int w, int h,
   if (height < 0)
     height = -height;
 
-  std::vector<unsigned int> raster_(w*h);
-  for ( size_t i = 0 ; i < raster_.size(); i++) {
-    raster_[i] = raster[i] ;
-  }
-
-  std::string base64_str = gdtools::raster_to_str(raster_, w, h, width*(25/6), height*(25/6), interpolate);
+  std::string base64_str = raster_to_string(raster, w, h, width, height, interpolate);
 
   SVGElement* image = svgd->svg_element("image", true);
   set_attr(image, "x", x);
@@ -479,6 +473,11 @@ static void dsvg_raster(unsigned int *raster, int w, int h,
   set_attr(image, "width", width);
   set_attr(image, "height", height);
   set_attr(image, "id", eltid);
+  set_attr(image, "preserveAspectRatio", "none");
+  if (!interpolate) {
+    set_attr(image, "image-rendering", "pixelated");
+  }
+
   set_clip(image, clipid);
 
   if (fabs(rot)>0.001) {
@@ -501,7 +500,7 @@ static SEXP dsvg_setPattern(SEXP pattern, pDevDesc dd) {
     return R_NilValue;
 }
 
-static void dsvg_releasePattern(SEXP ref, pDevDesc dd) {} 
+static void dsvg_releasePattern(SEXP ref, pDevDesc dd) {}
 
 static SEXP dsvg_setClipPath(SEXP path, SEXP ref, pDevDesc dd) {
     return R_NilValue;
@@ -514,7 +513,7 @@ static SEXP dsvg_setMask(SEXP path, SEXP ref, pDevDesc dd) {
 }
 
 static void dsvg_releaseMask(SEXP ref, pDevDesc dd) {}
-  
+
 static void dsvg_new_page(const pGEcontext gc, pDevDesc dd) {
   DSVG_dev *svgd = (DSVG_dev*) dd->deviceSpecific;
 
